summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--server/lib/external-backends/backends/idoit-backend.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/server/lib/external-backends/backends/idoit-backend.js b/server/lib/external-backends/backends/idoit-backend.js
index 6a91100..7f99138 100644
--- a/server/lib/external-backends/backends/idoit-backend.js
+++ b/server/lib/external-backends/backends/idoit-backend.js
@@ -923,8 +923,8 @@ class IdoitBackend extends ExternalBackends {
if (!rackObjects.result || !rack.result) return undefined
- // Check if the parent object is a rack else return this function (Type C__CATS__ENCLOSURE)
- if (rack.result[0].type.const !== 'C__CATS__ENCLOSURE' || rack.result[0].type.title !== 'Rack') return undefined
+ // Check if the parent object is a rack else return this function (Type C__OBJTYPE__ENCLOSURE)
+ if (rack.result[0].type.const !== 'C__OBJTYPE__ENCLOSURE' || rack.result[0].type.title !== 'Rack') return undefined
const rackName = rack.result[0].title
let rackSegmentId